nba_py
=======================

A python facing API for stats.nba.com RESTful API, partially based off
of https://github.com/bradleyfay/NBAStats.

All data returned is returned as a DataFrame from the pandas module
